You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@wicket.apache.org by jc...@apache.org on 2007/04/10 20:16:39 UTC

svn commit: r527232 [20/28] - in /incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src: main/java/ main/java/org/ main/java/org/apache/ main/java/org/apache/wicket/ main/java/org/apache/wicket/ajax/ main/java/org/apache/wicket/ajax/calldecorator/ ma...

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/upload/FileItemFactory.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/upload/FileItemFactory.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/upload/FileItemFactory.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/upload/FileItemFactory.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/upload/FileItemFactory.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/upload/FileItemFactory.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/upload/FileItemFactory.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.upload;
+package org.apache.wicket.util.upload;
 
 
 /**

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/upload/FileUpload.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/upload/FileUpload.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/upload/FileUpload.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/upload/FileUpload.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/upload/FileUpload.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/upload/FileUpload.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/upload/FileUpload.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.upload;
+package org.apache.wicket.util.upload;
 
 
 /**

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/upload/FileUploadBase.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/upload/FileUploadBase.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/upload/FileUploadBase.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/upload/FileUploadBase.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/upload/FileUploadBase.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/upload/FileUploadBase.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/upload/FileUploadBase.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.upload;
+package org.apache.wicket.util.upload;
 
 import java.io.IOException;
 import java.io.InputStream;

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/upload/FileUploadException.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/upload/FileUploadException.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/upload/FileUploadException.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/upload/FileUploadException.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/upload/FileUploadException.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/upload/FileUploadException.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/upload/FileUploadException.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.upload;
+package org.apache.wicket.util.upload;
 
 /**
  * Exception for errors encountered while processing the request.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/upload/MultipartFormInputStream.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/upload/MultipartFormInputStream.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/upload/MultipartFormInputStream.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/upload/MultipartFormInputStream.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/upload/MultipartFormInputStream.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/upload/MultipartFormInputStream.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/upload/MultipartFormInputStream.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.upload;
+package org.apache.wicket.util.upload;
 
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/upload/ParameterParser.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/upload/ParameterParser.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/upload/ParameterParser.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/upload/ParameterParser.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/upload/ParameterParser.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/upload/ParameterParser.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/upload/ParameterParser.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.upload;
+package org.apache.wicket.util.upload;
 
 import java.util.HashMap;
 import java.util.Map;

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/upload/RequestContext.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/upload/RequestContext.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/upload/RequestContext.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/upload/RequestContext.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/upload/RequestContext.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/upload/RequestContext.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/upload/RequestContext.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.upload;
+package org.apache.wicket.util.upload;
 
 import java.io.IOException;
 import java.io.InputStream;

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/upload/ServletFileUpload.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/upload/ServletFileUpload.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/upload/ServletFileUpload.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/upload/ServletFileUpload.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/upload/ServletFileUpload.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/upload/ServletFileUpload.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/upload/ServletFileUpload.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.upload;
+package org.apache.wicket.util.upload;
 
 import java.util.List;
 
@@ -31,7 +31,7 @@
  * <code>multipart/mixed</code> encoding type, as specified by <a
  * href="http://www.ietf.org/rfc/rfc1867.txt">RFC 1867</a>. Use {@link
  * #parseRequest(HttpServletRequest)} to acquire a list of {@link
- * wicket.util.upload.FileItem}s associated with a given HTML widget.
+ * org.apache.wicket.util.upload.FileItem}s associated with a given HTML widget.
  * </p>
  * 
  * <p>

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/upload/ServletRequestContext.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/upload/ServletRequestContext.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/upload/ServletRequestContext.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/upload/ServletRequestContext.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/upload/ServletRequestContext.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/upload/ServletRequestContext.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/upload/ServletRequestContext.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.upload;
+package org.apache.wicket.util.upload;
 
 import java.io.IOException;
 import java.io.InputStream;

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/value/AttributeMap.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/value/AttributeMap.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/value/AttributeMap.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/value/AttributeMap.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/value/AttributeMap.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/value/AttributeMap.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/value/AttributeMap.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.value;
+package org.apache.wicket.util.value;
 
 import java.util.Map;
 

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/value/CopyOnWriteValueMap.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/value/CopyOnWriteValueMap.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/value/CopyOnWriteValueMap.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/value/CopyOnWriteValueMap.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/value/CopyOnWriteValueMap.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/value/CopyOnWriteValueMap.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/value/CopyOnWriteValueMap.java Tue Apr 10 11:15:14 2007
@@ -14,17 +14,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.value;
+package org.apache.wicket.util.value;
 
 import java.io.Serializable;
 import java.util.Collection;
 import java.util.Map;
 import java.util.Set;
 
-import wicket.util.string.StringValue;
-import wicket.util.string.StringValueConversionException;
-import wicket.util.time.Duration;
-import wicket.util.time.Time;
+import org.apache.wicket.util.string.StringValue;
+import org.apache.wicket.util.string.StringValueConversionException;
+import org.apache.wicket.util.time.Duration;
+import org.apache.wicket.util.time.Time;
+
 
 /**
  * A implementation that takes a IValueMap that could be immutable but makes a

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/value/Count.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/value/Count.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/value/Count.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/value/Count.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/value/Count.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/value/Count.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/value/Count.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.value;
+package org.apache.wicket.util.value;
 
-import wicket.IClusterable;
+import org.apache.wicket.IClusterable;
 
 /**
  * A class for counting things.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/value/IValueMap.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/value/IValueMap.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/value/IValueMap.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/value/IValueMap.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/value/IValueMap.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/value/IValueMap.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/value/IValueMap.java Tue Apr 10 11:15:14 2007
@@ -14,14 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.value;
+package org.apache.wicket.util.value;
 
 import java.util.Map;
 
-import wicket.util.string.StringValue;
-import wicket.util.string.StringValueConversionException;
-import wicket.util.time.Duration;
-import wicket.util.time.Time;
+import org.apache.wicket.util.string.StringValue;
+import org.apache.wicket.util.string.StringValueConversionException;
+import org.apache.wicket.util.time.Duration;
+import org.apache.wicket.util.time.Time;
+
 
 
 /**

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/value/IntValue.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/value/IntValue.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/value/IntValue.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/value/IntValue.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/value/IntValue.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/value/IntValue.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/value/IntValue.java Tue Apr 10 11:15:14 2007
@@ -14,11 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.value;
+package org.apache.wicket.util.value;
 
 import java.io.Serializable;
 
-import wicket.util.lang.Primitives;
+import org.apache.wicket.util.lang.Primitives;
+
 
 /**
  * A base class for value classes based on a Java int primitive which want to

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/value/LongValue.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/value/LongValue.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/value/LongValue.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/value/LongValue.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/value/LongValue.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/value/LongValue.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/value/LongValue.java Tue Apr 10 11:15:14 2007
@@ -14,11 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.value;
+package org.apache.wicket.util.value;
 
 import java.io.Serializable;
 
-import wicket.util.lang.Primitives;
+import org.apache.wicket.util.lang.Primitives;
+
 
 /**
  * A base class for value classes based on a Java long primitive which want to

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/value/ValueMap.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/value/ValueMap.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/value/ValueMap.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/value/ValueMap.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/value/ValueMap.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/value/ValueMap.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/value/ValueMap.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.value;
+package org.apache.wicket.util.value;
 
 import java.lang.reflect.Array;
 import java.util.Arrays;
@@ -22,14 +22,15 @@
 import java.util.Iterator;
 import java.util.Map;
 
-import wicket.util.parse.metapattern.MetaPattern;
-import wicket.util.parse.metapattern.parsers.VariableAssignmentParser;
-import wicket.util.string.IStringIterator;
-import wicket.util.string.StringList;
-import wicket.util.string.StringValue;
-import wicket.util.string.StringValueConversionException;
-import wicket.util.time.Duration;
-import wicket.util.time.Time;
+import org.apache.wicket.util.parse.metapattern.MetaPattern;
+import org.apache.wicket.util.parse.metapattern.parsers.VariableAssignmentParser;
+import org.apache.wicket.util.string.IStringIterator;
+import org.apache.wicket.util.string.StringList;
+import org.apache.wicket.util.string.StringValue;
+import org.apache.wicket.util.string.StringValueConversionException;
+import org.apache.wicket.util.time.Duration;
+import org.apache.wicket.util.time.Time;
+
 
 /**
  * A Map implementation that holds values, parses strings and exposes a variety

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/watch/IModifiable.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/watch/IModifiable.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/watch/IModifiable.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/watch/IModifiable.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/watch/IModifiable.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/watch/IModifiable.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/watch/IModifiable.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.watch;
+package org.apache.wicket.util.watch;
 
-import wicket.util.time.Time;
+import org.apache.wicket.util.time.Time;
 
 /**
  * Interface to get the last time something was modified.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/watch/ModificationWatcher.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/watch/ModificationWatcher.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/watch/ModificationWatcher.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/watch/ModificationWatcher.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/watch/ModificationWatcher.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/watch/ModificationWatcher.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/watch/ModificationWatcher.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.watch;
+package org.apache.wicket.util.watch;
 
 import java.util.ArrayList;
 import java.util.HashMap;
@@ -23,13 +23,13 @@
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.util.listener.ChangeListenerSet;
+import org.apache.wicket.util.listener.IChangeListener;
+import org.apache.wicket.util.thread.ICode;
+import org.apache.wicket.util.thread.Task;
+import org.apache.wicket.util.time.Duration;
+import org.apache.wicket.util.time.Time;
 
-import wicket.util.listener.ChangeListenerSet;
-import wicket.util.listener.IChangeListener;
-import wicket.util.thread.ICode;
-import wicket.util.thread.Task;
-import wicket.util.time.Duration;
-import wicket.util.time.Time;
 
 /**
  * Monitors one or more Modifiable objects, calling a ChangeListener when a

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/watch/Watcher.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/watch/Watcher.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/watch/Watcher.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/watch/Watcher.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/watch/Watcher.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/util/watch/Watcher.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/util/watch/Watcher.java Tue Apr 10 11:15:14 2007
@@ -14,13 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.watch;
+package org.apache.wicket.util.watch;
 
 import java.util.Map;
 
-import wicket.util.concurrent.ConcurrentHashMap;
-import wicket.util.listener.ChangeListenerSet;
-import wicket.util.listener.IChangeListener;
+import org.apache.wicket.util.concurrent.ConcurrentHashMap;
+import org.apache.wicket.util.listener.ChangeListenerSet;
+import org.apache.wicket.util.listener.IChangeListener;
+
 
 /**
  * Similar to ModificationWatcher but manually triggered, calling all registered

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/IErrorMessageSource.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/IErrorMessageSource.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/IErrorMessageSource.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/IErrorMessageSource.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/IErrorMessageSource.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/IErrorMessageSource.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/IErrorMessageSource.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.validation;
+package org.apache.wicket.validation;
 
 import java.util.Map;
 

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/IValidatable.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/IValidatable.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/IValidatable.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/IValidatable.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/IValidatable.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/IValidatable.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/IValidatable.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.validation;
+package org.apache.wicket.validation;
 
 
 /**

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/IValidationError.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/IValidationError.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/IValidationError.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/IValidationError.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/IValidationError.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/IValidationError.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/IValidationError.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.validation;
+package org.apache.wicket.validation;
 
 /**
  * A validation error

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/IValidator.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/IValidator.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/IValidator.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/IValidator.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/IValidator.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/IValidator.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/IValidator.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.validation;
+package org.apache.wicket.validation;
 
 import java.io.Serializable;
 

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/ValidationError.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/ValidationError.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/ValidationError.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/ValidationError.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/ValidationError.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/ValidationError.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/ValidationError.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.validation;
+package org.apache.wicket.validation;
 
 import java.io.Serializable;
 import java.util.ArrayList;
@@ -140,7 +140,7 @@
 	}
 
 	/**
-	 * @see wicket.validation.IValidationError#getErrorMessage(wicket.validation.IErrorMessageSource)
+	 * @see org.apache.wicket.validation.IValidationError#getErrorMessage(org.apache.wicket.validation.IErrorMessageSource)
 	 */
 	public final String getErrorMessage(IErrorMessageSource messageSource)
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/validator/AbstractValidator.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/validator/AbstractValidator.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/validator/AbstractValidator.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/validator/AbstractValidator.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/validator/AbstractValidator.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/validator/AbstractValidator.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/validator/AbstractValidator.java Tue Apr 10 11:15:14 2007
@@ -14,17 +14,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.validation.validator;
+package org.apache.wicket.validation.validator;
 
 import java.util.HashMap;
 import java.util.Map;
 
-import wicket.IClusterable;
-import wicket.markup.html.form.FormComponent;
-import wicket.util.lang.Classes;
-import wicket.validation.IValidatable;
-import wicket.validation.IValidator;
-import wicket.validation.ValidationError;
+import org.apache.wicket.IClusterable;
+import org.apache.wicket.markup.html.form.FormComponent;
+import org.apache.wicket.util.lang.Classes;
+import org.apache.wicket.validation.IValidatable;
+import org.apache.wicket.validation.IValidator;
+import org.apache.wicket.validation.ValidationError;
+
 
 /**
  * Convinience base class for {@link IValidator}s. This class is thread-safe
@@ -71,7 +72,7 @@
 	protected abstract void onValidate(IValidatable validatable);
 
 	/**
-	 * @see wicket.validation.IValidator#validate(wicket.validation.IValidatable)
+	 * @see org.apache.wicket.validation.IValidator#validate(org.apache.wicket.validation.IValidatable)
 	 */
 	public final void validate(IValidatable validatable)
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/validator/CreditCardValidator.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/validator/CreditCardValidator.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/validator/CreditCardValidator.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/validator/CreditCardValidator.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/validator/CreditCardValidator.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/validator/CreditCardValidator.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/validator/CreditCardValidator.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.validation.validator;
+package org.apache.wicket.validation.validator;
 
-import wicket.validation.IValidatable;
+import org.apache.wicket.validation.IValidatable;
 
 /**
  * Performs the so called "mod 10" algorithm to check the validity of credit
@@ -32,7 +32,7 @@
 	private static final long serialVersionUID = 1L;
 
 	/**
-	 * @see wicket.validation.validator.AbstractValidator#onValidate(wicket.validation.IValidatable)
+	 * @see org.apache.wicket.validation.validator.AbstractValidator#onValidate(org.apache.wicket.validation.IValidatable)
 	 */
 	protected void onValidate(IValidatable validatable)
 	{
@@ -60,7 +60,7 @@
 	}
 
 	/**
-	 * @see wicket.validation.validator.AbstractValidator#resourceKey()
+	 * @see org.apache.wicket.validation.validator.AbstractValidator#resourceKey()
 	 */
 	protected String resourceKey()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/validator/DateValidator.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/validator/DateValidator.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/validator/DateValidator.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/validator/DateValidator.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/validator/DateValidator.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/validator/DateValidator.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/validator/DateValidator.java Tue Apr 10 11:15:14 2007
@@ -14,12 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.validation.validator;
+package org.apache.wicket.validation.validator;
 
 import java.util.Date;
 import java.util.Map;
 
-import wicket.validation.IValidatable;
+import org.apache.wicket.validation.IValidatable;
+
 
 /**
  * A validator for dates that can be used for subclassing or use one of the
@@ -134,7 +135,7 @@
 		}
 
 		/**
-		 * @see wicket.markup.html.form.validation.AbstractValidator#resourceKey(wicket.markup.html.form.FormComponent)
+		 * @see org.apache.wicket.markup.html.form.validation.AbstractValidator#resourceKey(org.apache.wicket.markup.html.form.FormComponent)
 		 */
 		protected String resourceKey()
 		{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/validator/EmailAddressPatternValidator.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/validator/EmailAddressPatternValidator.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/validator/EmailAddressPatternValidator.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/validator/EmailAddressPatternValidator.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/validator/EmailAddressPatternValidator.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/validator/EmailAddressPatternValidator.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/validator/EmailAddressPatternValidator.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.validation.validator;
+package org.apache.wicket.validation.validator;
 
 import java.util.regex.Pattern;
 

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/validator/EmailAddressValidator.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/validator/EmailAddressValidator.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/validator/EmailAddressValidator.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/validator/EmailAddressValidator.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/validator/EmailAddressValidator.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/validator/EmailAddressValidator.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/validator/EmailAddressValidator.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.validation.validator;
+package org.apache.wicket.validation.validator;
 
 import java.util.regex.Pattern;
 

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/validator/NumberValidator.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/validator/NumberValidator.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/validator/NumberValidator.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/validator/NumberValidator.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/validator/NumberValidator.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/validator/NumberValidator.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/validator/NumberValidator.java Tue Apr 10 11:15:14 2007
@@ -14,11 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.validation.validator;
+package org.apache.wicket.validation.validator;
 
 import java.util.Map;
 
-import wicket.validation.IValidatable;
+import org.apache.wicket.validation.IValidatable;
+
 
 /**
  * FIXME 2.0: ivaynberg: look over javadoc
@@ -223,7 +224,7 @@
 		}
 
 		/**
-		 * @see wicket.markup.html.form.validation.AbstractValidator#resourceKey(wicket.markup.html.form.FormComponent)
+		 * @see org.apache.wicket.markup.html.form.validation.AbstractValidator#resourceKey(org.apache.wicket.markup.html.form.FormComponent)
 		 */
 		protected String resourceKey()
 		{
@@ -259,7 +260,7 @@
 		}
 
 		/**
-		 * @see wicket.markup.html.form.validation.AbstractValidator#resourceKey(wicket.markup.html.form.FormComponent)
+		 * @see org.apache.wicket.markup.html.form.validation.AbstractValidator#resourceKey(org.apache.wicket.markup.html.form.FormComponent)
 		 */
 		protected String resourceKey()
 		{
@@ -295,7 +296,7 @@
 		}
 
 		/**
-		 * @see wicket.markup.html.form.validation.AbstractValidator#resourceKey(wicket.markup.html.form.FormComponent)
+		 * @see org.apache.wicket.markup.html.form.validation.AbstractValidator#resourceKey(org.apache.wicket.markup.html.form.FormComponent)
 		 */
 		protected String resourceKey()
 		{
@@ -366,7 +367,7 @@
 		}
 
 		/**
-		 * @see wicket.markup.html.form.validation.AbstractValidator#resourceKey(wicket.markup.html.form.FormComponent)
+		 * @see org.apache.wicket.markup.html.form.validation.AbstractValidator#resourceKey(org.apache.wicket.markup.html.form.FormComponent)
 		 */
 		protected String resourceKey()
 		{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/validator/PatternValidator.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/validator/PatternValidator.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/validator/PatternValidator.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/validator/PatternValidator.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/validator/PatternValidator.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/validator/PatternValidator.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/validator/PatternValidator.java Tue Apr 10 11:15:14 2007
@@ -14,13 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.validation.validator;
+package org.apache.wicket.validation.validator;
 
 import java.util.Map;
 import java.util.regex.Pattern;
 
-import wicket.util.parse.metapattern.MetaPattern;
-import wicket.validation.IValidatable;
+import org.apache.wicket.util.parse.metapattern.MetaPattern;
+import org.apache.wicket.validation.IValidatable;
+
 
 /**
  * FIXME 2.0: ivaynberg: look over javadoc
@@ -38,7 +39,7 @@
  * MetaPattern.DIGITS. The advantages of using MetaPattern over straight Java
  * regular expressions are that the patterns are easier to construct and easier
  * to combine into complex patterns. They are also more readable and more
- * reusable. See {@link wicket.util.parse.metapattern.MetaPattern}for details.
+ * reusable. See {@link org.apache.wicket.util.parse.metapattern.MetaPattern}for details.
  * <p>
  * The error message will be generated with the key "PatternValidator" and the
  * messages keys that can be used are:
@@ -52,7 +53,7 @@
  * </ul>
  * 
  * @see java.util.regex.Pattern
- * @see wicket.util.parse.metapattern.MetaPattern
+ * @see org.apache.wicket.util.parse.metapattern.MetaPattern
  * @author Jonathan Locke *
  * @author Igor Vaynberg(ivaynberg)
  * 

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/validator/StringValidator.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/validator/StringValidator.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/validator/StringValidator.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/validator/StringValidator.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/validator/StringValidator.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/validation/validator/StringValidator.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/validation/validator/StringValidator.java Tue Apr 10 11:15:14 2007
@@ -14,11 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.validation.validator;
+package org.apache.wicket.validation.validator;
 
 import java.util.Map;
 
-import wicket.validation.IValidatable;
+import org.apache.wicket.validation.IValidatable;
+
 
 /**
  * FIXME 2.0: ivaynberg: look over javadoc
@@ -164,7 +165,7 @@
 		}
 
 		/**
-		 * @see wicket.markup.html.form.validation.AbstractValidator#resourceKey(wicket.markup.html.form.FormComponent)
+		 * @see org.apache.wicket.markup.html.form.validation.AbstractValidator#resourceKey(org.apache.wicket.markup.html.form.FormComponent)
 		 */
 		protected String resourceKey()
 		{
@@ -202,7 +203,7 @@
 		}
 
 		/**
-		 * @see wicket.markup.html.form.validation.AbstractValidator#resourceKey(wicket.markup.html.form.FormComponent)
+		 * @see org.apache.wicket.markup.html.form.validation.AbstractValidator#resourceKey(org.apache.wicket.markup.html.form.FormComponent)
 		 */
 		protected String resourceKey()
 		{
@@ -238,7 +239,7 @@
 		}
 
 		/**
-		 * @see wicket.markup.html.form.validation.AbstractValidator#resourceKey(wicket.markup.html.form.FormComponent)
+		 * @see org.apache.wicket.markup.html.form.validation.AbstractValidator#resourceKey(org.apache.wicket.markup.html.form.FormComponent)
 		 */
 		protected String resourceKey()
 		{
@@ -274,7 +275,7 @@
 		}
 
 		/**
-		 * @see wicket.markup.html.form.validation.AbstractValidator#resourceKey(wicket.markup.html.form.FormComponent)
+		 * @see org.apache.wicket.markup.html.form.validation.AbstractValidator#resourceKey(org.apache.wicket.markup.html.form.FormComponent)
 		 */
 		protected String resourceKey()
 		{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/version/IPageVersionManager.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/version/IPageVersionManager.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/version/IPageVersionManager.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/version/IPageVersionManager.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/version/IPageVersionManager.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/version/IPageVersionManager.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/version/IPageVersionManager.java Tue Apr 10 11:15:14 2007
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.version;
+package org.apache.wicket.version;
 
-import wicket.Component;
-import wicket.IClusterable;
-import wicket.Page;
-import wicket.version.undo.Change;
+import org.apache.wicket.Component;
+import org.apache.wicket.IClusterable;
+import org.apache.wicket.Page;
+import org.apache.wicket.version.undo.Change;
 
 /**
  * Interface to code that manages versions of a Page. Initially a page has a

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/version/undo/Add.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/version/undo/Add.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/version/undo/Add.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/version/undo/Add.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/version/undo/Add.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/version/undo/Add.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/version/undo/Add.java Tue Apr 10 11:15:14 2007
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.version.undo;
+package org.apache.wicket.version.undo;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.Component;
+import org.apache.wicket.util.lang.Classes;
 
-import wicket.Component;
-import wicket.util.lang.Classes;
 
 /**
  * An add change operation.
@@ -66,7 +66,7 @@
 	}
 
 	/**
-	 * @see wicket.version.undo.Change#undo()
+	 * @see org.apache.wicket.version.undo.Change#undo()
 	 */
 	public void undo()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/version/undo/Change.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/version/undo/Change.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/version/undo/Change.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/version/undo/Change.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/version/undo/Change.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/version/undo/Change.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/version/undo/Change.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.version.undo;
+package org.apache.wicket.version.undo;
 
-import wicket.IClusterable;
+import org.apache.wicket.IClusterable;
 
 /**
  * Undo information for a change to the page.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/version/undo/ChangeList.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/version/undo/ChangeList.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/version/undo/ChangeList.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/version/undo/ChangeList.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/version/undo/ChangeList.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/version/undo/ChangeList.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/version/undo/ChangeList.java Tue Apr 10 11:15:14 2007
@@ -14,16 +14,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.version.undo;
+package org.apache.wicket.version.undo;
 
 import java.util.ArrayList;
 import java.util.List;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.Component;
+import org.apache.wicket.IClusterable;
 
-import wicket.Component;
-import wicket.IClusterable;
 
 /**
  * A ChangeList is a sequence of changes that can be undone.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/version/undo/ModelChange.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/version/undo/ModelChange.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/version/undo/ModelChange.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/version/undo/ModelChange.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/version/undo/ModelChange.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/version/undo/ModelChange.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/version/undo/ModelChange.java Tue Apr 10 11:15:14 2007
@@ -14,17 +14,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.version.undo;
+package org.apache.wicket.version.undo;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.Component;
+import org.apache.wicket.markup.html.form.FormComponent;
+import org.apache.wicket.model.CompoundPropertyModel;
+import org.apache.wicket.model.IModel;
+import org.apache.wicket.util.lang.Classes;
+import org.apache.wicket.util.lang.Objects;
 
-import wicket.Component;
-import wicket.markup.html.form.FormComponent;
-import wicket.model.CompoundPropertyModel;
-import wicket.model.IModel;
-import wicket.util.lang.Classes;
-import wicket.util.lang.Objects;
 
 /**
  * A model change operation.
@@ -114,7 +114,7 @@
 	}
 
 	/**
-	 * @see wicket.version.undo.Change#undo()
+	 * @see org.apache.wicket.version.undo.Change#undo()
 	 */
 	public void undo()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/version/undo/Remove.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/version/undo/Remove.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/version/undo/Remove.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/version/undo/Remove.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/version/undo/Remove.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/version/undo/Remove.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/version/undo/Remove.java Tue Apr 10 11:15:14 2007
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.version.undo;
+package org.apache.wicket.version.undo;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.Component;
+import org.apache.wicket.MarkupContainer;
+import org.apache.wicket.util.lang.Classes;
 
-import wicket.Component;
-import wicket.MarkupContainer;
-import wicket.util.lang.Classes;
 
 /**
  * A remove change operation.
@@ -71,7 +71,7 @@
 	}
 
 	/**
-	 * @see wicket.version.undo.Change#undo()
+	 * @see org.apache.wicket.version.undo.Change#undo()
 	 */
 	public void undo()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/version/undo/UndoPageVersionManager.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/version/undo/UndoPageVersionManager.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/version/undo/UndoPageVersionManager.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/version/undo/UndoPageVersionManager.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/version/undo/UndoPageVersionManager.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/version/undo/UndoPageVersionManager.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/version/undo/UndoPageVersionManager.java Tue Apr 10 11:15:14 2007
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.version.undo;
+package org.apache.wicket.version.undo;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.Component;
+import org.apache.wicket.Page;
+import org.apache.wicket.util.collections.ArrayListStack;
+import org.apache.wicket.version.IPageVersionManager;
 
-import wicket.Component;
-import wicket.Page;
-import wicket.util.collections.ArrayListStack;
-import wicket.version.IPageVersionManager;
 
 /**
  * A version manager implemented by recording component changes as undo records
@@ -74,7 +74,7 @@
 	}
 
 	/**
-	 * @see wicket.version.IPageVersionManager#beginVersion(boolean)
+	 * @see org.apache.wicket.version.IPageVersionManager#beginVersion(boolean)
 	 */
 	public void beginVersion(boolean mergeVersion)
 	{
@@ -95,7 +95,7 @@
 	}
 	
 	/**
-	 * @see wicket.version.IPageVersionManager#ignoreVersionMerge()
+	 * @see org.apache.wicket.version.IPageVersionManager#ignoreVersionMerge()
 	 */
 	public void ignoreVersionMerge()
 	{
@@ -105,7 +105,7 @@
 	}
 
 	/**
-	 * @see wicket.version.IPageVersionManager#componentAdded(wicket.Component)
+	 * @see org.apache.wicket.version.IPageVersionManager#componentAdded(org.apache.wicket.Component)
 	 */
 	public void componentAdded(Component component)
 	{
@@ -113,7 +113,7 @@
 	}
 
 	/**
-	 * @see wicket.version.IPageVersionManager#componentModelChanging(wicket.Component)
+	 * @see org.apache.wicket.version.IPageVersionManager#componentModelChanging(org.apache.wicket.Component)
 	 */
 	public void componentModelChanging(Component component)
 	{
@@ -121,7 +121,7 @@
 	}
 
 	/**
-	 * @see wicket.version.IPageVersionManager#componentRemoved(wicket.Component)
+	 * @see org.apache.wicket.version.IPageVersionManager#componentRemoved(org.apache.wicket.Component)
 	 */
 	public void componentRemoved(Component component)
 	{
@@ -129,7 +129,7 @@
 	}
 
 	/**
-	 * @see wicket.version.IPageVersionManager#componentStateChanging(wicket.version.undo.Change)
+	 * @see org.apache.wicket.version.IPageVersionManager#componentStateChanging(org.apache.wicket.version.undo.Change)
 	 */
 	public void componentStateChanging(Change change)
 	{
@@ -137,7 +137,7 @@
 	}
 
 	/**
-	 * @see wicket.version.IPageVersionManager#endVersion(boolean)
+	 * @see org.apache.wicket.version.IPageVersionManager#endVersion(boolean)
 	 */
 	public void endVersion(boolean mergeVersion)
 	{
@@ -180,7 +180,7 @@
 	}
 
 	/**
-	 * @see wicket.version.IPageVersionManager#getCurrentVersionNumber()
+	 * @see org.apache.wicket.version.IPageVersionManager#getCurrentVersionNumber()
 	 */
 	public int getCurrentVersionNumber()
 	{
@@ -188,7 +188,7 @@
 	}
 	
 	/**
-	 * @see wicket.version.IPageVersionManager#getAjaxVersionNumber()
+	 * @see org.apache.wicket.version.IPageVersionManager#getAjaxVersionNumber()
 	 */
 	public int getAjaxVersionNumber()
 	{
@@ -196,7 +196,7 @@
 	}
 
 	/**
-	 * @see wicket.version.IPageVersionManager#getVersion(int)
+	 * @see org.apache.wicket.version.IPageVersionManager#getVersion(int)
 	 */
 	public Page getVersion(final int versionNumber)
 	{
@@ -224,7 +224,7 @@
 	}
 	
 	/**
-	 * @see wicket.version.IPageVersionManager#rollbackPage(int)
+	 * @see org.apache.wicket.version.IPageVersionManager#rollbackPage(int)
 	 */
 	public Page rollbackPage(int numberOfVersions)
 	{
@@ -233,7 +233,7 @@
 	}
 
 	/**
-	 * @see wicket.version.IPageVersionManager#getVersions()
+	 * @see org.apache.wicket.version.IPageVersionManager#getVersions()
 	 */
 	public int getVersions()
 	{

Modified: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket.properties
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket.properties?view=diff&rev=527232&r1=527231&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket.properties (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket.properties Tue Apr 10 11:15:14 2007
@@ -12,4 +12,4 @@
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
-initializer=wicket.Initializer
+initializer=org.apache.wicket.Initializer

Modified: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/log4j.properties
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/log4j.properties?view=diff&rev=527232&r1=527231&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/log4j.properties (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/log4j.properties Tue Apr 10 11:15:14 2007
@@ -10,8 +10,8 @@
 # why there are stacktraces in the test output. You can turn it
 # down if you need to when testing, but don't check it in. (eelco)
 log4j.logger.wicket=FATAL
-#log4j.logger.wicket.resource=FATAL
-#log4j.logger.wicket.Localizer=FATAL
+#log4j.logger.org.apache.wicket.resource=FATAL
+#log4j.logger.org.apache.wicket.Localizer=FATAL
 
 log4j.appender.Stdout=org.apache.log4j.ConsoleAppender
 log4j.appender.Stdout.layout=org.apache.log4j.PatternLayout

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/ApplicationSettingsTest.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/ApplicationSettingsTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/ApplicationSettingsTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/ApplicationSettingsTest.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/ApplicationSettingsTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/ApplicationSettingsTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/ApplicationSettingsTest.java Tue Apr 10 11:15:14 2007
@@ -14,17 +14,19 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
 import java.util.List;
 
+import org.apache.wicket.Application;
+import org.apache.wicket.resource.loader.BundleStringResourceLoader;
+import org.apache.wicket.resource.loader.ClassStringResourceLoader;
+import org.apache.wicket.resource.loader.ComponentStringResourceLoader;
+import org.apache.wicket.settings.Settings;
+import org.apache.wicket.util.tester.WicketTester;
+
 import junit.framework.Assert;
 import junit.framework.TestCase;
-import wicket.resource.loader.BundleStringResourceLoader;
-import wicket.resource.loader.ClassStringResourceLoader;
-import wicket.resource.loader.ComponentStringResourceLoader;
-import wicket.settings.Settings;
-import wicket.util.tester.WicketTester;
 
 /**
  * Test cases for the <code>ApplicationSettings</code> class.
@@ -116,7 +118,7 @@
 		Application dummy = tester.getApplication();
 		Settings settings = new Settings(dummy);
 		settings.addStringResourceLoader(new BundleStringResourceLoader(
-				"wicket.resource.DummyResources"));
+				"org.apache.wicket.resource.DummyResources"));
 		settings.addStringResourceLoader(new ComponentStringResourceLoader());
 		List loaders = settings.getStringResourceLoaders();
 		Assert.assertEquals("There should be 2 overridden loaders", 2, loaders.size());

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/AttributeModifierComponentPage.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/AttributeModifierComponentPage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/AttributeModifierComponentPage.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/AttributeModifierComponentPage.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/AttributeModifierComponentPage.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/AttributeModifierComponentPage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/AttributeModifierComponentPage.java Tue Apr 10 11:15:14 2007
@@ -14,12 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
-import wicket.markup.html.WebPage;
-import wicket.markup.html.basic.Label;
-import wicket.model.LoadableDetachableModel;
-import wicket.model.Model;
+import org.apache.wicket.AttributeModifier;
+import org.apache.wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.basic.Label;
+import org.apache.wicket.model.LoadableDetachableModel;
+import org.apache.wicket.model.Model;
 
 /**
  * Test page used for checking the attribute modification functionality of

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/AttributeModifierComponentTest.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/AttributeModifierComponentTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/AttributeModifierComponentTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/AttributeModifierComponentTest.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/AttributeModifierComponentTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/AttributeModifierComponentTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/AttributeModifierComponentTest.java Tue Apr 10 11:15:14 2007
@@ -14,18 +14,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
 import junit.framework.Assert;
 import junit.framework.TestCase;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.protocol.http.documentvalidation.HtmlDocumentValidator;
+import org.apache.wicket.protocol.http.documentvalidation.Tag;
+import org.apache.wicket.protocol.http.documentvalidation.TextContent;
+import org.apache.wicket.util.tester.WicketTester;
 
-import wicket.protocol.http.documentvalidation.HtmlDocumentValidator;
-import wicket.protocol.http.documentvalidation.Tag;
-import wicket.protocol.http.documentvalidation.TextContent;
-import wicket.util.tester.WicketTester;
 
 /**
  * This set of tests builds a sample tester for testing the dynamic modicication

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/AttributeModifierTest.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/AttributeModifierTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/AttributeModifierTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/AttributeModifierTest.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/AttributeModifierTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/AttributeModifierTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/AttributeModifierTest.java Tue Apr 10 11:15:14 2007
@@ -14,15 +14,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
 import java.util.Map;
 
+import org.apache.wicket.AttributeModifier;
+import org.apache.wicket.markup.ComponentTag;
+import org.apache.wicket.markup.parser.XmlTag;
+import org.apache.wicket.model.Model;
+
 import junit.framework.Assert;
 import junit.framework.TestCase;
-import wicket.markup.ComponentTag;
-import wicket.markup.parser.XmlTag;
-import wicket.model.Model;
 
 /**
  * Test case for the component tag attribute modifer test.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/AuthorizationTest.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/AuthorizationTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/AuthorizationTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/AuthorizationTest.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/AuthorizationTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/ComponentTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/ComponentTest.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
-import wicket.ajax.AjaxEventBehavior;
+import org.apache.wicket.ajax.AjaxEventBehavior;
 
 /**
  * Test for ajax handler.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/DisabledComponentPage1.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/DisabledComponentPage1.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/DisabledComponentPage1.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/DisabledComponentPage1.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/DisabledComponentPage1.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/DisabledComponentPage1.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/DisabledComponentPage1.java Tue Apr 10 11:15:14 2007
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
-import wicket.markup.html.WebPage;
-import wicket.markup.html.link.Link;
+import org.apache.wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.link.Link;
 
 
 /**

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/DisabledComponentPage2.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/DisabledComponentPage2.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/DisabledComponentPage2.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/DisabledComponentPage2.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/DisabledComponentPage2.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/DisabledComponentPage2.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/DisabledComponentPage2.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
-import wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.WebPage;
 
 /**
  * @author jcompagner

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/DisabledComponentTest.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/DisabledComponentTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/DisabledComponentTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/DisabledComponentTest.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/DisabledComponentTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/DisabledComponentTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/DisabledComponentTest.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
-import wicket.markup.html.link.Link;
+import org.apache.wicket.markup.html.link.Link;
 
 /**
  * @author jcompagner

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/FormDispatchEventTest.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/FormDispatchEventTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/FormDispatchEventTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/FormDispatchEventTest.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/FormDispatchEventTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/FormDispatchEventTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/FormDispatchEventTest.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
-import wicket.util.tester.FormTester;
+import org.apache.wicket.util.tester.FormTester;
 
 /**
  * @author jcompagner

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/HomePageRedirectTest.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/HomePageRedirectTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/HomePageRedirectTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/HomePageRedirectTest.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/HomePageRedirectTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/HomePageRedirectTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/HomePageRedirectTest.java Tue Apr 10 11:15:14 2007
@@ -14,10 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
+
+import org.apache.wicket.markup.html.WebPage;
+import org.apache.wicket.util.tester.WicketTester;
 
-import wicket.markup.html.WebPage;
-import wicket.util.tester.WicketTester;
 import junit.framework.TestCase;
 
 /**

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/LocalizerTest.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/LocalizerTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/LocalizerTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/LocalizerTest.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/LocalizerTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/LocalizerTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/LocalizerTest.java Tue Apr 10 11:15:14 2007
@@ -14,19 +14,24 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
 import java.util.Locale;
 import java.util.MissingResourceException;
 
+import org.apache.wicket.Application;
+import org.apache.wicket.Component;
+import org.apache.wicket.Localizer;
+import org.apache.wicket.Session;
+import org.apache.wicket.markup.html.basic.Label;
+import org.apache.wicket.model.Model;
+import org.apache.wicket.resource.DummyApplication;
+import org.apache.wicket.resource.loader.ComponentStringResourceLoader;
+import org.apache.wicket.settings.IResourceSettings;
+import org.apache.wicket.util.tester.WicketTester;
+import org.apache.wicket.util.value.ValueMap;
+
 import junit.framework.Assert;
-import wicket.markup.html.basic.Label;
-import wicket.model.Model;
-import wicket.resource.DummyApplication;
-import wicket.resource.loader.ComponentStringResourceLoader;
-import wicket.settings.IResourceSettings;
-import wicket.util.tester.WicketTester;
-import wicket.util.value.ValueMap;
 
 /**
  * Test cases for the <code>Localizer</code> class.
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/AuthorizationTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/AuthorizationTest.java Tue Apr 10 11:15:14 2007
@@ -14,19 +14,22 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
 import java.io.Serializable;
 
-import wicket.authorization.Action;
-import wicket.authorization.AuthorizationException;
-import wicket.authorization.IAuthorizationStrategy;
-import wicket.markup.html.WebComponent;
-import wicket.markup.html.WebPage;
-import wicket.markup.html.basic.Label;
-import wicket.markup.html.form.Form;
-import wicket.markup.html.form.TextField;
-import wicket.model.CompoundPropertyModel;
+import org.apache.wicket.Component;
+import org.apache.wicket.WicketRuntimeException;
+import org.apache.wicket.authorization.Action;
+import org.apache.wicket.authorization.AuthorizationException;
+import org.apache.wicket.authorization.IAuthorizationStrategy;
+import org.apache.wicket.markup.html.WebComponent;
+import org.apache.wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.basic.Label;
+import org.apache.wicket.markup.html.form.Form;
+import org.apache.wicket.markup.html.form.TextField;
+import org.apache.wicket.model.CompoundPropertyModel;
+
 
 /**
  * Authorization tests.
@@ -114,8 +117,8 @@
 		tester.getApplication().getSecuritySettings().setAuthorizationStrategy(new DummyAuthorizationStrategy()
 		{
 			/**
-			 * @see wicket.authorization.IAuthorizationStrategy#isActionAuthorized(wicket.Component,
-			 *      wicket.authorization.Action)
+			 * @see org.apache.wicket.authorization.IAuthorizationStrategy#isActionAuthorized(org.apache.wicket.Component,
+			 *      org.apache.wicket.authorization.Action)
 			 */
 			public boolean isActionAuthorized(Component component, Action action)
 			{
@@ -162,7 +165,7 @@
 		tester.getApplication().getSecuritySettings().setAuthorizationStrategy(new DummyAuthorizationStrategy()
 		{
 			/**
-			 * @see wicket.authorization.IAuthorizationStrategy#isActionAuthorized(wicket.Component, wicket.authorization.Action)
+			 * @see org.apache.wicket.authorization.IAuthorizationStrategy#isActionAuthorized(org.apache.wicket.Component, org.apache.wicket.authorization.Action)
 			 */
 			public boolean isActionAuthorized(Component c, Action action)
 			{
@@ -196,7 +199,7 @@
 	private static class DummyAuthorizationStrategy implements IAuthorizationStrategy
 	{
 		/**
-		 * @see wicket.authorization.IAuthorizationStrategy#isInstantiationAuthorized(java.lang.Class)
+		 * @see org.apache.wicket.authorization.IAuthorizationStrategy#isInstantiationAuthorized(java.lang.Class)
 		 */
 		public boolean isInstantiationAuthorized(Class c)
 		{
@@ -204,8 +207,8 @@
 		}
 
 		/**
 		 * @see wicket.authorization.IAuthorizationStrategy#isActionAuthorized(
 		 *      wicket.Component, wicket.authorization.Action)
 		 */
 		public boolean isActionAuthorized(Component c, Action action)
 		{
@@ -272,7 +275,7 @@
 			}
 
 			/**
-			 * @see wicket.markup.html.form.Form#onSubmit()
+			 * @see org.apache.wicket.markup.html.form.Form#onSubmit()
 			 */
 			protected void onSubmit()
 			{
@@ -204,8 +207,8 @@
 
 		/**
-		 * @see wicket.authorization.IAuthorizationStrategy#isActionAuthorized(
-		 *      wicket.Component, wicket.authorization.Action)
+		 * @see org.apache.wicket.authorization.IAuthorizationStrategy#isActionAuthorized(
+		 *      org.apache.wicket.Component, org.apache.wicket.authorization.Action)
 		 */
 		public boolean isActionAuthorized(Component c, Action action)

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/ComponentTest.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/ComponentTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/ComponentTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/ComponentTest.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/ComponentTest.java&r2=527232
==============================================================================